@@ -17,7 +17,8 @@ import warnings
 from collections import OrderedDict, namedtuple
 from string import digits
 
-VersionInfo = namedtuple("VersionInfo", ["major", "minor", "micro", "releaselevel", "serial"])
+VersionInfo = namedtuple("VersionInfo", ["major", "minor", "micro", "releaselevel", "serial"])  # noqa: PYI024
+LOGGER = logging.getLogger(__name__)
 
 
 def _get_path_extensions():
@@ -28,7 +29,7 @@ EXTENSIONS = _get_path_extensions()
 _CONF_VAR_RE = re.compile(r"\{\w+\}")
 
 
-class PythonInfo:
+class PythonInfo:  # noqa: PLR0904
     """Contains information for a Python interpreter."""
 
     def __init__(self) -> None:  # noqa: PLR0915
@@ -112,8 +113,7 @@ class PythonInfo:
 
         config_var_keys = set()
         for element in self.sysconfig_paths.values():
-            for k in _CONF_VAR_RE.findall(element):
-                config_var_keys.add(k[1:-1])
+            config_var_keys.update(k[1:-1] for k in _CONF_VAR_RE.findall(element))
         config_var_keys.add("PYTHONFRAMEWORK")
 
         self.sysconfig_vars = {i: sysconfig.get_config_var(i or "") for i in config_var_keys}
@@ -129,7 +129,7 @@ class PythonInfo:
 
     def _fast_get_system_executable(self):
         """Try to get the system executable by just looking at properties."""
-        if self.real_prefix or (
+        if self.real_prefix or (  # noqa: PLR1702
             self.base_prefix is not None and self.base_prefix != self.prefix
         ):  # if this is a virtual environment
             if self.real_prefix is None:
@@ -175,8 +175,8 @@ class PythonInfo:
         with warnings.catch_warnings():  # disable warning for PEP-632
             warnings.simplefilter("ignore")
             try:
-                from distutils import dist
-                from distutils.command.install import SCHEME_KEYS
+                from distutils import dist  # noqa: PLC0415
+                from distutils.command.install import SCHEME_KEYS  # noqa: PLC0415
             except ImportError:  # if removed or not installed ignore
                 return {}
 
@@ -225,7 +225,7 @@ class PythonInfo:
 
     def creators(self, refresh=False):  # noqa: FBT002
         if self._creators is None or refresh is True:
-            from virtualenv.run.plugin.creators import CreatorSelector
+            from virtualenv.run.plugin.creators import CreatorSelector  # noqa: PLC0415
 
             self._creators = CreatorSelector.for_interpreter(self)
         return self._creators
@@ -254,9 +254,6 @@ class PythonInfo:
     def system_exec_prefix(self):
         return self.real_prefix or self.base_exec_prefix or self.exec_prefix
 
-    def __unicode__(self):
-        return repr(self)
-
     def __repr__(self) -> str:
         return "{}({!r})".format(
             self.__class__.__name__,
@@ -298,7 +295,7 @@ class PythonInfo:
     @classmethod
     def clear_cache(cls, app_data):
         # this method is not used by itself, so here and called functions can import stuff locally
-        from virtualenv.discovery.cached_py_info import clear
+        from virtualenv.discovery.cached_py_info import clear  # noqa: PLC0415
 
         clear(app_data)
         cls._cache_exe_discovery.clear()
@@ -348,7 +345,7 @@ class PythonInfo:
         return cls._current
 
     @classmethod
-    def current_system(cls, app_data=None):
+    def current_system(cls, app_data=None) -> PythonInfo:
         """
         This locates the current host interpreter information. This might be different than what we run into in case
         the host python has been upgraded from underneath us.
@@ -362,7 +359,7 @@ class PythonInfo:
         return json.dumps(self._to_dict(), indent=2)
 
     def _to_dict(self):
-        data = {var: (getattr(self, var) if var not in ("_creators",) else None) for var in vars(self)}
+        data = {var: (getattr(self, var) if var != "_creators" else None) for var in vars(self)}
 
         data["version_info"] = data["version_info"]._asdict()  # namedtuple to dictionary
         return data
@@ -379,7 +376,7 @@ class PythonInfo:
     ):
         """Given a path to an executable get the python information."""
         # this method is not used by itself, so here and called functions can import stuff locally
-        from virtualenv.discovery.cached_py_info import from_exe
+        from virtualenv.discovery.cached_py_info import from_exe  # noqa: PLC0415
 
         env = os.environ if env is None else env
         proposed = from_exe(cls, app_data, exe, env=env, raise_on_error=raise_on_error, ignore_cache=ignore_cache)
@@ -387,10 +384,10 @@ class PythonInfo:
         if isinstance(proposed, PythonInfo) and resolve_to_host:
             try:
                 proposed = proposed._resolve_to_system(app_data, proposed)  # noqa: SLF001
-            except Exception as exception:  # noqa: BLE001
+            except Exception as exception:
                 if raise_on_error:
                     raise
-                logging.info("ignore %s due cannot resolve system due to %r", proposed.original_executable, exception)
+                LOGGER.info("ignore %s due cannot resolve system due to %r", proposed.original_executable, exception)
                 proposed = None
         return proposed
 
@@ -416,12 +413,12 @@ class PythonInfo:
             if prefix in prefixes:
                 if len(prefixes) == 1:
                     # if we're linking back to ourselves accept ourselves with a WARNING
-                    logging.info("%r links back to itself via prefixes", target)
+                    LOGGER.info("%r links back to itself via prefixes", target)
                     target.system_executable = target.executable
                     break
                 for at, (p, t) in enumerate(prefixes.items(), start=1):
-                    logging.error("%d: prefix=%s, info=%r", at, p, t)
-                logging.error("%d: prefix=%s, info=%r", len(prefixes) + 1, prefix, target)
+                    LOGGER.error("%d: prefix=%s, info=%r", at, p, t)
+                LOGGER.error("%d: prefix=%s, info=%r", len(prefixes) + 1, prefix, target)
                 msg = "prefixes are causing a circle {}".format("|".join(prefixes.keys()))
                 raise RuntimeError(msg)
             prefixes[prefix] = target
@@ -436,9 +433,9 @@ class PythonInfo:
     def discover_exe(self, app_data, prefix, exact=True, env=None):  # noqa: FBT002
         key = prefix, exact
         if key in self._cache_exe_discovery and prefix:
-            logging.debug("discover exe from cache %s - exact %s: %r", prefix, exact, self._cache_exe_discovery[key])
+            LOGGER.debug("discover exe from cache %s - exact %s: %r", prefix, exact, self._cache_exe_discovery[key])
             return self._cache_exe_discovery[key]
-        logging.debug("discover exe for %s in %s", self, prefix)
+        LOGGER.debug("discover exe for %s in %s", self, prefix)
         # we don't know explicitly here, do some guess work - our executable name should tell
         possible_names = self._find_possible_exe_names()
         possible_folders = self._find_possible_folders(prefix)
@@ -454,7 +451,7 @@ class PythonInfo:
             info = self._select_most_likely(discovered, self)
             folders = os.pathsep.join(possible_folders)
             self._cache_exe_discovery[key] = info
-            logging.debug("no exact match found, chosen most similar of %s within base folders %s", info, folders)
+            LOGGER.debug("no exact match found, chosen most similar of %s within base folders %s", info, folders)
             return info
         msg = "failed to detect {} in {}".format("|".join(possible_names), os.pathsep.join(possible_folders))
         raise RuntimeError(msg)
@@ -473,7 +470,7 @@ class PythonInfo:
                 if item == "version_info":
                     found, searched = ".".join(str(i) for i in found), ".".join(str(i) for i in searched)
                 executable = info.executable
-                logging.debug("refused interpreter %s because %s differs %s != %s", executable, item, found, searched)
+                LOGGER.debug("refused interpreter %s because %s differs %s != %s", executable, item, found, searched)
                 if exact is False:
                     discovered.append(info)
                 break
@@ -543,7 +540,7 @@ class PythonInfo:
         for base in possible_base:
             lower = base.lower()
             yield lower
-            from virtualenv.info import fs_is_case_sensitive
+            from virtualenv.info import fs_is_case_sensitive  # noqa: PLC0415
 
             if fs_is_case_sensitive():
                 if base != lower:
